This directory contains additional code implementing the extensions described in our paper [Relaxing Local Robustness](https://arxiv.org/pdf/2106.06624.pdf) (appearing in NIPS 2021). If you use code from this directory (e.g., `RtkGloroNet`, `AffinityGloroNet`) please use both of the following citations:

```bibtex
@INPROCEEDINGS{leino21gloro,
    title = {Globally-Robust Neural Networks},
    author = {Klas Leino and Zifan Wang and Matt Fredrikson},
    booktitle = {International Conference on Machine Learning (ICML)},
    year = {2021},
}
```

```bibtex
@INPROCEEDINGS{leino2021relaxing,
  title = {Relaxing Local Robustness},
  author = {Klas Leino and Matt Fredrikson},
  booktitle = {Neural Information Processing Systems (NIPS)},
  year = {2021}
}
```
